#!/system/bin/sh
#----------------------------------------------------
# Yank555.lu - Kernel options init.d script generator
#----------------------------------------------------

script_path="/tmp/Yank555.lu/script"
script_name="init.kernel.sh"
log_file="/data/kernel-script.log"
sub_scripts_path="$script_path/sub-scripts"
props_path="/tmp/aroma"
bin_path="/tmp/Yank555.lu/bin"

# Start making the script header -----------------------------------------------------------------

$bin_path/echo "----------------------------------------------------" >$log_file
$bin_path/echo "Kernel options init.d script generator by Yank555.lu" >>$log_file
$bin_path/echo "----------------------------------------------------" >>$log_file
$bin_path/date "+Script generated on %d/%m/%Y at %k:%M" >>$log_file
$bin_path/echo "----------------------------------------------------" >>$log_file
$bin_path/echo "" >>$log_file
$bin_path/echo "1) Preparing init.d script header" >>$log_file

$bin_path/rm $script_path/$script_name >>$log_file
$bin_path/cp $sub_scripts_path/header $script_path/$script_name >>$log_file
$bin_path/date "+# Script generated on %d/%m/%Y at %k:%M" >>$script_path/$script_name
$bin_path/echo "#----------------------------------------------------" >>$script_path/$script_name
$bin_path/echo "" >>$script_path/$script_name

# Add CPU configuration --------------------------------------------------------------------------

$bin_path/echo "" >>$log_file
$bin_path/echo "2) CPU configuration" >>$log_file

if [ "`$bin_path/grep selected.1 $props_path/cpu.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     CPU max freq. = `$bin_path/grep selected.1 $props_path/cpu.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/cpu/1.`$bin_path/grep selected.1 $props_path/cpu.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`$bin_path/grep selected.2 $props_path/cpu.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     IO is busy    = `$bin_path/grep selected.2 $props_path/cpu.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/cpu/2.`$bin_path/grep selected.2 $props_path/cpu.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Virtual memory configuration -------------------------------------------------------------------

$bin_path/echo "" >>$log_file
$bin_path/echo "3) Virtual memory configuration" >>$log_file

if [ "`$bin_path/grep selected.2 $props_path/swap.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     Zram     = `$bin_path/grep selected.2 $props_path/swap.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/swap/2.`$bin_path/grep selected.2 $props_path/swap.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`$bin_path/grep selected.1 $props_path/swap.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     Hardswap = `$bin_path/grep selected.1 $props_path/swap.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/swap/1.`$bin_path/grep selected.1 $props_path/swap.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Fast charge configuration ----------------------------------------------------------------------

$bin_path/echo "" >>$log_file
$bin_path/echo "4) Fast charge configuration" >>$log_file

if [ "`$bin_path/grep selected.1 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     Mode = `$bin_path/grep selected.1 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/charge/1.`$bin_path/grep selected.1 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`$bin_path/grep selected.2 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     USB  = `$bin_path/grep selected.2 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/charge/2.`$bin_path/grep selected.2 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`$bin_path/grep selected.3 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     AC   = `$bin_path/grep selected.3 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/charge/3.`$bin_path/grep selected.3 $props_path/charge.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add MMC I/O configuration ----------------------------------------------------------------------

$bin_path/echo "" >>$log_file
$bin_path/echo "5) MMC I/O configuration" >>$log_file

if [ "`$bin_path/grep selected.1 $props_path/io.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     ReadAhead size  = `$bin_path/grep selected.1 $props_path/io.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/io/1.`$bin_path/grep selected.1 $props_path/io.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`$bin_path/grep selected.2 $props_path/io.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     I/O scheduler   = `$bin_path/grep selected.2 $props_path/io.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/io/2.`$bin_path/grep selected.2 $props_path/io.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add Android Low Memory Killer configuration ----------------------------------------------------

$bin_path/echo "" >>$log_file
$bin_path/echo "6) Android Low Memory Killer configuration" >>$log_file

if [ "`$bin_path/grep selected.1 $props_path/lmk.prop | $bin_path/awk -F= '{print $2;}'`" != "" ]
  then
    $bin_path/echo "     Android LMK = `$bin_path/grep selected.1 $props_path/lmk.prop | $bin_path/awk -F= '{print $2;}'`" >>$log_file
    $bin_path/cat $sub_scripts_path/lmk/1.`$bin_path/grep selected.1 $props_path/lmk.prop | $bin_path/awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

$bin_path/cat $sub_scripts_path/footer >>$script_path/$script_name

# Installing generated script to system init -----------------------------------------------------

$bin_path/echo "" >>$log_file
$bin_path/echo "7) Installing generated script to /system/etc" >>$log_file

$bin_path/rm /system/etc/$script_name
$bin_path/cp $script_path/$script_name /system/etc/$script_name
$bin_path/chmod 755 /system/etc/$script_name
$bin_path/chown 0:2000 /system/etc/$script_name

# All done for this step -------------------------------------------------------------------------